@@ -9,6 +9,7 @@ import (
 )
 
 func TestDetermineUpdates(t *testing.T) {
+	t.Parallel()
 	maxConns := 1
 	tests := []struct {
 		updated          []UpstreamServer
@@ -162,6 +163,7 @@ func TestDetermineUpdates(t *testing.T) {
 }
 
 func TestStreamDetermineUpdates(t *testing.T) {
+	t.Parallel()
 	maxConns := 1
 	tests := []struct {
 		updated          []StreamUpstreamServer
@@ -318,6 +320,7 @@ func TestStreamDetermineUpdates(t *testing.T) {
 }
 
 func TestAddPortToServer(t *testing.T) {
+	t.Parallel()
 	// More info about addresses http://nginx.org/en/docs/http/ngx_http_upstream_module.html#server
 	tests := []struct {
 		address  string
@@ -370,6 +373,7 @@ func TestAddPortToServer(t *testing.T) {
 }
 
 func TestHaveSameParameters(t *testing.T) {
+	t.Parallel()
 	tests := []struct {
 		server    UpstreamServer
 		serverNGX UpstreamServer
@@ -449,6 +453,7 @@ func TestHaveSameParameters(t *testing.T) {
 }
 
 func TestHaveSameParametersForStream(t *testing.T) {
+	t.Parallel()
 	tests := []struct {
 		server    StreamUpstreamServer
 		serverNGX StreamUpstreamServer
@@ -523,8 +528,9 @@ func TestHaveSameParametersForStream(t *testing.T) {
 }
 
 func TestClientWithCheckAPI(t *testing.T) {
+	t.Parallel()
 	// Create a test server that returns supported API versions
-	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 		_, err := w.Write([]byte(`[4, 5, 6, 7, 8, 9]`))
 		if err != nil {
 			t.Fatalf("unexpected error: %v", err)
@@ -552,6 +558,7 @@ func TestClientWithCheckAPI(t *testing.T) {
 }
 
 func TestClientWithAPIVersion(t *testing.T) {
+	t.Parallel()
 	// Test creating a new client with a supported API version on the client
 	client, err := NewNginxClient("http://api-url", WithAPIVersion(8))
 	if err != nil {
@@ -572,6 +579,7 @@ func TestClientWithAPIVersion(t *testing.T) {
 }
 
 func TestClientWithHTTPClient(t *testing.T) {
+	t.Parallel()
 	// Test creating a new client passing a custom HTTP client
 	client, err := NewNginxClient("http://api-url", WithHTTPClient(&http.Client{}))
 	if err != nil {
@@ -592,20 +600,22 @@ func TestClientWithHTTPClient(t *testing.T) {
 }
 
 func TestGetStats_NoStreamEndpoint(t *testing.T) {
+	t.Parallel()
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		if r.RequestURI == "/" {
+		switch {
+		case r.RequestURI == "/":
 			_, err := w.Write([]byte(`[4, 5, 6, 7, 8, 9]`))
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
-		} else if r.RequestURI == "/7/" {
+		case r.RequestURI == "/7/":
 			_, err := w.Write([]byte(`["nginx","processes","connections","slabs","http","resolvers","ssl"]`))
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
-		} else if strings.HasPrefix(r.RequestURI, "/7/stream") {
+		case strings.HasPrefix(r.RequestURI, "/7/stream"):
 			t.Fatal("Stream endpoint should not be called since it does not exist.")
-		} else {
+		default:
 			_, err := w.Write([]byte(`{}`))
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
@@ -637,24 +647,26 @@ func TestGetStats_NoStreamEndpoint(t *testing.T) {
 	if !reflect.DeepEqual(stats.StreamUpstreams, StreamUpstreams{}) {
 		t.Fatalf("StreamUpstreams: expected %v, actual %v", StreamUpstreams{}, stats.StreamUpstreams)
 	}
-	if !reflect.DeepEqual(stats.StreamZoneSync, &StreamZoneSync{}) {
-		t.Fatalf("StreamZoneSync: expected %v, actual %v", &StreamZoneSync{}, stats.StreamZoneSync)
+	if stats.StreamZoneSync != nil {
+		t.Fatalf("StreamZoneSync: expected %v, actual %v", nil, stats.StreamZoneSync)
 	}
 }
 
 func TestGetStats_SSL(t *testing.T) {
+	t.Parallel()
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
-		if r.RequestURI == "/" {
+		switch {
+		case r.RequestURI == "/":
 			_, err := w.Write([]byte(`[4, 5, 6, 7, 8, 9]`))
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
-		} else if r.RequestURI == "/8/" {
+		case r.RequestURI == "/8/":
 			_, err := w.Write([]byte(`["nginx","processes","connections","slabs","http","resolvers","ssl","workers"]`))
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
-		} else if strings.HasPrefix(r.RequestURI, "/8/ssl") {
+		case strings.HasPrefix(r.RequestURI, "/8/ssl"):
 			_, err := w.Write([]byte(`{
 				"handshakes" : 79572,
 				"handshakes_failed" : 21025,
@@ -674,7 +686,7 @@ func TestGetStats_SSL(t *testing.T) {
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
-		} else {
+		default:
 			_, err := w.Write([]byte(`{}`))
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
